#!/bin/bash

# Packager: Filippo "NeverBorn" Mesirca (filippo.mesirca@gmail.com)
# Sources location : 
# - ftp://ftp.proftpd.org/distrib/source/proftpd-1.2.10.tar.bz2

# program name/version
softversion='1.2.10'
softname='proftpd'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='1z21'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
proftpd: ProFTPD (version: 1.2.10)
proftpd:
proftpd: ProFTPD is a highly configurable FTP daemon for Unix and Unix-ilke
proftpd: operating systems. ProFTPD grew from a desire for a secure and
proftpd: configurable FTP server. It was inspired by a significant
proftpd: admiration of the Apache web server. It has not been derived from
proftpd: the old BSD ftpd code base, but is  a completely new design and
proftpd: implementation.
proftpd:
proftpd:
proftpd: Compiled for ZenWalk-2.1
EOF

# extract sources
srcdir="proftpd-$softversion"
cd $buildir
rm -rf $srcdir
tar jxvf $srcdir.tar.bz2
cd $srcdir

# set correct permissions
chown -R root.root . 
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
 
# configure package for compilation
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
   --prefix=/usr \
   --sysconfdir=/etc \
   --localstatedir=/var/run \
   --enable-autoshadow \
   --enable-cap \
   --enable-ctrls \
   --enable-ipv6 \
   --with-modules=mod_radius:mod_readme:mod_rewrite:mod_tls:mod_wrap
   
# compile package
make $ntasks

# install package to the target directory
make install DESTDIR=$dest
    
# copy the doc files
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   COPYING CREDITS ChangeLog INSTALL NEWS README* RELEASE_NOTES contrib/INSTALL.mod_wrap contrib/README.mod_wrap contrib/README \
   $dest/usr/doc/$softname-$softversion

# rename the configuration files
mv $dest/etc/proftpd.conf $dest/etc/proftpd.conf.new

# strip executables 
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)
  
# gzip man pages and info files
gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
cp -a $buildir/doinst.sh.gz $dest/usr/src/$softname-$softversion

# change files ownerships for the $dest/usr/bin and $dest/usr/sbin
chown -R root.bin $dest/usr/bin
chown -R root.bin $dest/usr/sbin

# make the package and move it to the build directory
zcat $buildir/doinst.sh.gz > $dest/install/doinst.sh
cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5

